powered by
This functions allows us to transform non-normal multivariate data to that of non paranormal data.
npn(x, npn_func = "shrinkage", npn_thresh = NULL, verbose = TRUE)
The multivariate non-normal data to be transformed.
Optional parameter - The method of transformation to be applied. Can either be "shrinkage" or "truncation" but defaults to "shrinkage".
Optional parameter - The truncation threshold that is used when making use of truncation.
Optional parameter - Prints additional output of the selected approach. Can either be "TRUE" or "FALSE" and defaults to "TRUE".
Returns the transformed data matrix.
# NOT RUN { data <- data_generator(n = 100, p = 50, seed = 123) X <- data$X X_transformed <- npn(X, npn_func = "truncation") # }
Run the code above in your browser using DataLab